﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using PdfSharp.Drawing;
using PdfSharp.Fonts;
using PdfSharp.Pdf;

namespace FontResolver
{
    /// <summary>
    /// This sample demonstrated the use of the PDFsharp font resolver.
    /// </summary>
    class Program
    {
        static void Main()
        {
            // Register font resolver before start using PDFsharp.
            GlobalFontSettings.FontResolver = new SegoeWpFontResolver();
            GlobalFontSettings.DefaultFontEncoding = PdfFontEncoding.Windows1252;  // We use only "WinANSI" characters.

            // Create a new PDF document.
            var document = new PdfDocument();
            document.Info.Title = "Font Resolver Sample";

            // Create an empty page in this document.
            var page = document.AddPage();

            // Get an XGraphics object for drawing on this PDF page.
            var gfx = XGraphics.FromPdfPage(page);

            // Create some fonts.
            const double fontSize = 16;

            XFont wpLightFont = new XFont("Segoe WP Light", fontSize, XFontStyle.Regular);
            XFont wpSemilightFont = new XFont("Segoe WP Semilight", fontSize, XFontStyle.Regular);
            XFont wpRegularFont = new XFont("Segoe WP", fontSize, XFontStyle.Regular);
            XFont wpSemiboldFont = new XFont("Segoe WP Semibold", fontSize, XFontStyle.Regular);
            XFont wpBlackFont = new XFont("Segoe WP Black", fontSize, XFontStyle.Regular);

            XFont wpBoldFont = new XFont("Segoe WP", fontSize, XFontStyle.Bold);
            XFont wpBlackItalicFont = new XFont("Segoe WP Black", fontSize, XFontStyle.Italic);
            XFont wpLightItalicFont = new XFont("Segoe WP Light", fontSize, XFontStyle.Italic);
            XFont wpLightBoldFont = new XFont("Segoe WP Light", fontSize, XFontStyle.Bold);
            XFont wpLightBoldItalicFont = new XFont("Segoe WP Light", fontSize, XFontStyle.BoldItalic);

            // Draw the text.
            const string text = "Sphinx ";
            const double x = 40;
            double y = 50;
            const double dy = 35;

            gfx.DrawString(text + "(Segoe WP Light - regular)", wpLightFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP Semilight - regular)", wpSemilightFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP - regular)", wpRegularFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP Semibold - regular)", wpSemiboldFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP - bold)", wpBoldFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP Black - regular)", wpBlackFont, XBrushes.Black, x, y);
            y += dy;


            gfx.DrawString(text + "(Segoe WP Light - with italic simulated)", wpLightItalicFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP Light - bold)", wpLightBoldFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP Light - bold with italic simulated)", wpLightBoldItalicFont, XBrushes.Black, x, y);
            y += dy;

            gfx.DrawString(text + "(Segoe WP Black - with italic simulated)", wpBlackItalicFont, XBrushes.Black, x, y);
            y += dy;

            // Note: PDFsharp produces a PDF file with 10 embedded fonts, although 6 are enough. This makes the PDF file a
            // a little bit larger as necessary and will be fixed.

            // Save the document...
            const string filename = "FontResolver_tempfile.pdf";
            document.Save(filename);
            // ...and start a viewer.
            Process.Start(filename);
        }
    }
}
